# Welcome to Muscle X Application Suite! 
The Muscle X program suite is a collection of programs intended to assist with analyzing diffraction X-ray images. 

# The collection includes:
* Equator (eq)
* Quadrant Folding (qf)
* Projection Traces (pt)
* Circular Projection (cp)
* Diffraction Centroids (dc)
* DDF Processor (ddf)

## For more information, Please go to our wiki page at https://musclex.readthedocs.io/
